# sklearn-viz
[![PyPI](https://img.shields.io/pypi/v/sklearn-viz.svg?logo=python&logoColor=white)](https://pypi.org/project/sklearn-viz/)
[![Run Tests](https://github.com/Elphick/sklearn-viz/actions/workflows/poetry_build_and_test.yml/badge.svg?branch=main)](https://github.com/Elphick/sklearn-viz/actions/workflows/poetry_build_and_test.yml)
[![Publish Docs](https://github.com/Elphick/sklearn-viz/actions/workflows/poetry_sphinx_docs_to_gh_pages.yml/badge.svg?branch=main)](https://github.com/Elphick/sklearn-viz/actions/workflows/poetry_sphinx_docs_to_gh_pages.yml)

This package provides a collection of interactive (plotly) plots to facilitate scikit-learn model evaluation.

It is very early days, but with time it is hoped the toolset will broaden to provide similar tools to those of the
great [yellowbrick](https://www.scikit-yb.org/en/latest/) package, but with interactive plots built in plotly.


